@@ -1,5 +1,4 @@
 from distutils import log
-from typing import List
 
 from weaverbird.backends.sql_translator.steps.utils.query_transformation import (
     build_selection_query,
@@ -14,16 +13,6 @@ from weaverbird.backends.sql_translator.types import (
 from weaverbird.pipeline.steps import ConvertStep
 
 
-def format_cast_to_sql(columns: List, data_type: str, completed_fields: str) -> (str, str):
-    """
-    From cast to sql
-    """
-    compiled_query: str = ""
-    for c in columns:
-        compiled_query = ", ".join([f"CAST({c} AS {data_type}) AS {c.upper()}" for c in columns])
-    return compiled_query
-
-
 def translate_convert(
     step: ConvertStep,
     query: SQLQuery,
@@ -42,17 +31,14 @@ def translate_convert(
         f"step.data_type: {step.data_type}\n"
         f"query.transformed_query: {query.transformed_query}\n"
         f"query.metadata_manager.tables_metadata: {query.metadata_manager.tables_metadata}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.query_metadata}\n"
     )
 
     for c in step.columns:
-        for table in [*query.metadata_manager.tables_metadata]:
-            query.metadata_manager.change_type(
-                column_name=c, table_name=table, new_type=step.data_type
-            )
+        query.metadata_manager.change_type(column_name=c, new_type=step.data_type)
     completed_fields = complete_fields(columns=step.columns, query=query)
-    compiled_query = format_cast_to_sql(
-        step.columns, step.data_type, completed_fields=completed_fields
-    )
+    compiled_query = ", ".join([f"CAST({c} AS {step.data_type}) AS {c}" for c in step.columns])
+
     if len(completed_fields):
         compiled_query = f', {compiled_query}'
     new_query = SQLQuery(
@@ -60,7 +46,7 @@ def translate_convert(
         transformed_query=f"""{query.transformed_query}, {query_name} AS"""
         f""" (SELECT {completed_fields}{compiled_query}"""
         f""" FROM {query.query_name}) """,
-        selection_query=build_selection_query(query.metadata_manager.tables_metadata, query_name),
+        selection_query=build_selection_query(query.metadata_manager.query_metadata, query_name),
         metadata_manager=query.metadata_manager,
     )
 
