@@ -30,13 +30,14 @@ def translate_rename(
         f"step.to_rename: {step.to_rename}\n"
         f"query.transformed_query: {query.transformed_query}\n"
         f"query.metadata_manager.tables_metadata: {query.metadata_manager.tables_metadata}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.query_metadata}\n"
     )
 
     fields = []
     for old, new in step.to_rename:
-        for table in [*query.metadata_manager.tables_metadata]:
-            query.metadata_manager.change_name(old, new, table)
-            fields.append(new)
+        query.metadata_manager.change_name(old, new)
+        fields.append(new)
+
     completed_fields = complete_fields(columns=fields, query=query)
     renamed_fields = ', '.join([f'{old} AS {new.upper()}' for old, new in step.to_rename])
     if len(completed_fields):
@@ -46,8 +47,8 @@ def translate_rename(
         query_name=query_name,
         transformed_query=f"""{query.transformed_query}, {query_name} AS"""
         f""" (SELECT {completed_fields + renamed_fields}"""
-        f""" FROM {query.query_name}) """,
-        selection_query=build_selection_query(query.metadata_manager.tables_metadata, query_name),
+        f""" FROM {query.query_name})""",
+        selection_query=build_selection_query(query.metadata_manager.query_metadata, query_name),
         metadata_manager=query.metadata_manager,
     )
 
